# Symbiosil (Under development)

Symbiosil is open source AI bot framework. Our goal is to make living like symbiosis which can run on any platform and
device. Currently, we are developing this is python since gives simplicity and platform flexibility to developer. We also had planned to develop SDK for native platform under C/C++ umbrella. But that will be in next phase, currently 
python SDK will be available.

